@@ -1,17 +1,16 @@
 
 /*
  *  agCgi.c
- *  $Id: agCgi.c,v 4.19 2009/01/01 16:51:41 bkorb Exp $
+ *  $Id: 4c2c6233a5c8260899b7c2b5446bd78a09040304 $
  *
- *  Time-stamp:        "2007-07-04 11:14:03 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:41 $
+ *  Time-stamp:        "2010-02-24 08:43:40 bkorb"
  *
  *  This is a CGI wrapper for AutoGen.  It will take POST-method
  *  name-value pairs and emit AutoGen definitions to a spawned
  *  AutoGen process.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -77,7 +76,6 @@ static char const zOops[] =
 "AutoGen form processing error:\n";
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static char*
 parseInput( char* pzSrc, int len );
 /* = = = END-STATIC-FORWARD = = = */
@@ -96,7 +94,7 @@ loadCgi( void )
     pzOopsPrefix = zOops;
     {
         int tmpfd;
-        pzTmpStderr = mkstempPat();
+        AGDUPSTR(pzTmpStderr, mkstempPat(), "temp stderr file");
         tmpfd = mkstemp( pzTmpStderr );
         if (tmpfd < 0)
             AG_ABEND(aprf("failed to create temp file from `%s'", pzTmpStderr));
@@ -146,7 +144,7 @@ loadCgi( void )
             pBaseCtx->pzData = parseInput( pzCgiQuery, (int)textLen );
 
         } else {
-            AG_ABEND( aprf( "invalid CGI request method: ``%s''", pzCgiMethod ));
+            AG_ABEND( aprf("invalid CGI request method: ``%s''", pzCgiMethod));
             /* NOTREACHED */
 #ifdef  WARNING_WATCH
             pzText = NULL;
