@@ -1,14 +1,14 @@
 
 /*
- *  agInit.c  $Id: agInit.c,v 4.20 2009/01/01 16:51:41 bkorb Exp $
+ *  agInit.c  $Id: 3f9ebdee71c3b4b4df7d66ca617e124586188b27 $
  *
- *  Time-stamp:      "2008-12-31 14:06:19 bkorb"
+ *  Time-stamp:      "2010-04-20 07:21:20 bkorb"
  *
  *  Do all the initialization stuff.  For daemon mode, only
  *  children will return.
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -25,7 +25,6 @@
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
 addSysEnv( char* pzEnvName );
 /* = = = END-STATIC-FORWARD = = = */
@@ -55,7 +54,7 @@ initialize( int arg_ct, char** arg_vec )
             "(add-hook! before-error-hook error-source-line)\n"
             "(use-modules (ice-9 stack-catch))";
         pzLastScheme = zInitRest;
-        ag_scm_c_eval_string_from_file_line( zInitRest, __FILE__, __LINE__-3 );
+        ag_scm_c_eval_string_from_file_line(zInitRest, __FILE__, __LINE__-3);
     }
 #endif
 
@@ -66,11 +65,11 @@ initialize( int arg_ct, char** arg_vec )
      *  The lowest of the low is the config time install data dir.
      *  Next is the *current* directory of this executable.
      */
-    SET_OPT_TEMPL_DIRS( "$@" );
-    SET_OPT_TEMPL_DIRS( "$$/../share/autogen" );
+    SET_OPT_TEMPL_DIRS("$@");
+    SET_OPT_TEMPL_DIRS("$$/../share/autogen");
 
     {
-        char z[ 128 ] = "__autogen__";
+        char z[ SCRIBBLE_SIZE ] = "__autogen__";
 #if defined( HAVE_SOLARIS_SYSINFO )
         static const int nm[] = {
             SI_SYSNAME, SI_HOSTNAME, SI_ARCHITECTURE, SI_HW_PROVIDER,
@@ -130,13 +129,10 @@ initialize( int arg_ct, char** arg_vec )
         return;
 
     if (0) {
-        tSCC zDevNull[] =
-#ifndef DEBUG_ENABLED
-            "/dev/null";
-#else
-            "/tmp/AutoGenDebug.txt";
+#ifdef DEBUG_ENABLED
+        tSCC zDevNull[] = "/tmp/AutoGenDebug.txt";
 #endif /* DEBUG_ENABLED */
-        becomeDaemon( "/", zDevNull, zDevNull, zDevNull );
+        becomeDaemon("/", zDevNull, zDevNull, zDevNull);
     }
 
     {
@@ -259,7 +255,8 @@ spawnPipe( tCC* pzFile )
         polls[0].events = POLLIN | POLLPRI;
 
         for (;;) {
-            int ct = poll( polls, 1, -1 );
+            char const * pzerr;
+            int   ct = poll( polls, 1, -1 );
             struct strrecvfd recvfd;
             pid_t child;
 
@@ -285,7 +282,8 @@ spawnPipe( tCC* pzFile )
                     continue;
 
                 case -1:
-                    AG_ABEND(aprf(zCannot, errno, "fork", zNil, strerror(errno)));
+                    pzerr = strerror(errno);
+                    AG_ABEND(aprf(zCannot, errno, "fork", zNil, pzerr));
 
                 case 0:
                 }
@@ -297,13 +295,16 @@ spawnPipe( tCC* pzFile )
                 recvfd.fd = fdpair.readFd;
 #endif /* ! HAVE_FATTACH */
 
-                if (dup2( recvfd.fd, STDIN_FILENO ) != STDIN_FILENO)
-                    AG_ABEND( aprf(zCannot, errno, "dup2", "stdin",
-                                   strerror(errno)));
+                if (dup2( recvfd.fd, STDIN_FILENO ) != STDIN_FILENO) {
+                    pzerr = strerror(errno);
+                    AG_ABEND(aprf(zCannot, errno, "dup2", "stdin", pzerr);
+                }
+
+                if (dup2( fdpair.writeFd, STDOUT_FILENO ) != STDOUT_FILENO) {
+                    pzerr = strerror(errno);
+                    AG_ABEND(aprf(zCannot, errno, "dup2", "stdout", pzerr);
+                }
 
-                if (dup2( fdpair.writeFd, STDOUT_FILENO ) != STDOUT_FILENO)
-                    AG_ABEND( aprf(zCannot, errno, "dup2", "stdout",
-                                   strerror(errno)));
                 return;
             }
         }
@@ -350,6 +351,7 @@ spawnPipe( tCC* pzFile )
             int ct = poll( polls, 1, -1 );
             struct strrecvfd recvfd;
             pid_t child;
+            char const * pzerr;
 
             switch (ct) {
             case -1:
@@ -373,7 +375,8 @@ spawnPipe( tCC* pzFile )
                     continue;
 
                 case -1:
-                    AG_ABEND(aprf(zCannot, errno, "fork", zNil, strerror(errno)));
+                    pzerr = strerror(errno);
+                    AG_ABEND(aprf(zCannot, errno, "fork", zNil, pzerr));
 
                 case 0:
                 }
@@ -389,13 +392,18 @@ spawnPipe( tCC* pzFile )
 
                 polls[0].fd = fdpair.writeFd;
                 polls[0].events = POLLOUT;
-                if (poll( polls, 1, -1 ) != 1)
+                if (poll( polls, 1, -1 ) != 1) {
+                    pzerr = strerror(errno);
                     AG_ABEND( aprf(zCannot, errno, "poll", "write pipe",
-                                   strerror( errno )));
+                                   pzerr));
+                }
 
-                if (dup2( fdpair.writeFd, STDOUT_FILENO ) != STDOUT_FILENO)
+                if (dup2( fdpair.writeFd, STDOUT_FILENO ) != STDOUT_FILENO) {
+                    pzerr = strerror(errno);
                     AG_ABEND( aprf(zCannot, errno, "dup2", pzOut,
-                                   strerror(errno)));
+                                   pzerr));
+                }
+
                 return;
             }
         }
@@ -465,7 +473,8 @@ spawnListens( tCC* pzPort, sa_family_t addr_family )
     break;
 
     default:
-        AG_ABEND(aprf("The '%d' address family cannot be handled", addr_family));
+        AG_ABEND(aprf("The '%d' address family cannot be handled",
+                      addr_family));
     }
 
     if (bind( socket_fd, &sa.addr, addr_len ) < 0) {
@@ -512,7 +521,9 @@ spawnListens( tCC* pzPort, sa_family_t addr_family )
         if (new_conns > 0) {
             switch (fork()) {
             default: continue;
-            case -1: AG_ABEND(aprf(zCannot, errno, "fork", zNil,strerror(errno)));
+            case -1:
+                AG_ABEND(aprf(zCannot, errno, "fork", zNil,strerror(errno)));
+
             case 0:  break;
             }
             break;
