@@ -1,13 +1,13 @@
 /*  
  *  EDIT THIS FILE WITH CAUTION  (cgi-fsm.c)
  *  
- *  It has been AutoGen-ed  Wednesday December 31, 2008 at 07:07:29 PM PST
+ *  It has been AutoGen-ed  June 25, 2010 at 02:11:21 PM by AutoGen 5.10.1
  *  From the definitions    cgi.def
  *  and the template file   fsm
  *
  *  Automated Finite State Machine
  *
- *  copyright (c) 2001-2008 by Bruce Korb - all rights reserved
+ *  copyright (c) 2001-2009 by Bruce Korb - all rights reserved
  *
  *  AutoFSM is free software copyrighted by Bruce Korb.
  *  
@@ -221,10 +221,13 @@ cgi_run_fsm(
 
         /* END   == FIND TRANSITION == DO NOT CHANGE THIS COMMENT */
 
+#ifndef __COVERITY__
         if (trans_evt >= CGI_EV_INVALID) {
             nxtSt = CGI_ST_INVALID;
             trans = CGI_TR_INVALID;
-        } else {
+        } else
+#endif /* __COVERITY__ */
+        {
             const t_cgi_transition* pTT =
             cgi_trans_table[ cgi_state ] + trans_evt;
             nxtSt = pTT->next_state;
