@@ -1,9 +1,8 @@
 
 /*
- *  $Id: expPrint.c,v 4.23 2009/01/01 16:51:43 bkorb Exp $
+ *  $Id: 100084852a1db60587e81e6784adca552df51d70 $
  *
- *  Time-stamp:        "2007-12-02 12:43:09 bkorb"
- *  Last Committed:    $Date: 2009/01/01 16:51:43 $
+ *  Time-stamp:        "2010-02-24 08:42:58 bkorb"
  *
  *  The following code is necessary because the user can give us
  *  a printf format requiring a string pointer yet fail to provide
@@ -12,7 +11,7 @@
  *  a core dump :-)
  *
  *  This file is part of AutoGen.
- *  AutoGen copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoGen Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  * AutoGen is free software: you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
@@ -33,7 +32,6 @@ static int        printJumpSignal = 0;
 #endif
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static ssize_t
 safePrintf( char** ppzBuf, char* pzFmt, void** argV );
 /* = = = END-STATIC-FORWARD = = = */
@@ -272,15 +270,18 @@ ag_scm_fprintf( SCM port, SCM fmt, SCM alist )
 SCM
 ag_scm_hide_email( SCM display, SCM eaddr )
 {
-    tSCC zStrt[]  = "<script language=\"JavaScript\" type=\"text/javascript\">\n"
-                    "<!--\n"
-                    "var one = 'm&#97;';\n"
-                    "var two = 'i&#108;t';\n"
-                    "document.write('<a href=\"' + one + two );\n"
-                    "document.write('&#111;:";
+    tSCC zStrt[]  =
+        "<script language=\"JavaScript\" type=\"text/javascript\">\n"
+        "<!--\n"
+        "var one = 'm&#97;';\n"
+        "var two = 'i&#108;t';\n"
+        "document.write('<a href=\"' + one + two );\n"
+        "document.write('&#111;:";
+
     tSCC zEnd[]   = "');\n"
         "document.write('\" >%s</a>');\n"
         "//-->\n</script>";
+
     tSCC zFmt[]   = "&#%d;";
     char*  pzDisp = ag_scm2zchars( display, zFormat );
     char*  pzEadr = ag_scm2zchars( eaddr,   zFormat );
