@@ -1,12 +1,12 @@
 /*
- *  $Id: configfile.c,v 1.35 2009/01/18 22:48:51 bkorb Exp $
- *  Time-stamp:      "2009-01-18 10:21:58 bkorb"
+ *  $Id: f1650b45a91ec95af830ff76041cc4f0048e60f0 $
+ *  Time-stamp:      "2010-04-24 12:57:03 bkorb"
  *
  *  configuration/rc/ini file handling.
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is copyright (c) 1992-2009 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -20,13 +20,12 @@
  *
  *  These files have the following md5sums:
  *
- *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
- *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  43b91e8ca915626ed3818ffb1b71248b pkg/libopts/COPYING.gplv3
+ *  06a1a2e4760c90ea5e1dad8dfaac4d39 pkg/libopts/COPYING.lgplv3
  *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
 /* = = = START-STATIC-FORWARD = = = */
-/* static forward declarations maintained by mk-fwd */
 static void
 filePreset(
     tOptions*     pOpts,
@@ -417,6 +416,7 @@ filePreset(
 {
     tmap_info_t   cfgfile;
     tOptState     optst = OPTSTATE_INITIALIZER(PRESET);
+    tAoUL         st_flags = optst.flags;
     char*         pzFileText =
         text_mmap( pzFileName, PROT_READ|PROT_WRITE, MAP_PRIVATE, &cfgfile );
 
@@ -424,7 +424,7 @@ filePreset(
         return;
 
     if (direction == DIRECTION_CALLED) {
-        optst.flags = OPTST_DEFINED;
+        st_flags = OPTST_DEFINED;
         direction   = DIRECTION_PROCESS;
     }
 
@@ -435,9 +435,10 @@ filePreset(
      *  and we consider stuff set herein to be "set" by the client program.
      */
     if ((pOpts->fOptSet & OPTPROC_PRESETTING) == 0)
-        optst.flags = OPTST_SET;
+        st_flags = OPTST_SET;
 
     do  {
+        optst.flags = st_flags;
         while (IS_WHITESPACE_CHAR(*pzFileText))  pzFileText++;
 
         if (IS_VAR_FIRST_CHAR(*pzFileText)) {
