@@ -1,12 +1,11 @@
 
 /*
- *  $Id: numeric.c,v 4.19 2008/11/02 18:51:26 bkorb Exp $
- *  Time-stamp:      "2008-11-01 14:28:56 bkorb"
+ *  $Id: 52d772d69bed7f2911d88ff17b9a44308d6ca0b1 $
+ *  Time-stamp:      "2010-02-24 08:41:11 bkorb"
  *
  *  This file is part of AutoOpts, a companion to AutoGen.
  *  AutoOpts is free software.
- *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
- *  AutoOpts is copyright (c) 1992-2008 by Bruce Korb - all rights reserved
+ *  AutoOpts is Copyright (c) 1992-2010 by Bruce Korb - all rights reserved
  *
  *  AutoOpts is available under any one of two licenses.  The license
  *  in use must be one of these two and the choice is under the control
@@ -20,8 +19,8 @@
  *
  *  These files have the following md5sums:
  *
- *  239588c55c22c60ffe159946a760a33e pkg/libopts/COPYING.gplv3
- *  fa82ca978890795162346e661b47161a pkg/libopts/COPYING.lgplv3
+ *  43b91e8ca915626ed3818ffb1b71248b pkg/libopts/COPYING.gplv3
+ *  06a1a2e4760c90ea5e1dad8dfaac4d39 pkg/libopts/COPYING.lgplv3
  *  66a5cedaf62c4b2637025f049f9b826f pkg/libopts/COPYING.mbsd
  */
 
@@ -40,9 +39,14 @@
 void
 optionShowRange(tOptions* pOpts, tOptDesc* pOD, void * rng_table, int rng_ct)
 {
+    static char const bullet[] = "\t\t\t\t- ";
+    static char const deepin[] = "\t\t\t\t  ";
+    static char const onetab[] = "\t";
+
     const struct {long const rmin, rmax;} * rng = rng_table;
+
     char const * pz_indent =
-        (pOpts != OPTPROC_EMIT_USAGE) ? "\t" : "\t\t\t\t  ";
+        (pOpts != OPTPROC_EMIT_USAGE) ? onetab : bullet;
 
     if ((pOpts == OPTPROC_EMIT_USAGE) || (pOpts > OPTPROC_EMIT_LIMIT)) {
         char const * lie_in_range = zRangeLie;
@@ -58,10 +62,14 @@ optionShowRange(tOptions* pOpts, tOptDesc* pOD, void * rng_table, int rng_ct)
         if (pOD->fOptState & OPTST_SCALED_NUM)
             fprintf(option_usage_fp, zRangeScaled, pz_indent);
 
-        if (rng_ct > 1)
+        if (rng_ct > 1) {
             fprintf(option_usage_fp, lie_in_range, pz_indent);
-        else {
+            pz_indent =
+                (pOpts != OPTPROC_EMIT_USAGE) ? onetab : deepin;
+
+        } else {
             fprintf(option_usage_fp, zRangeOnly, pz_indent);
+            pz_indent = onetab + 1; /* empty string */
         }
 
         for (;;) {
@@ -81,6 +89,8 @@ optionShowRange(tOptions* pOpts, tOptDesc* pOD, void * rng_table, int rng_ct)
             }
             fputs(zRangeOr, option_usage_fp);
             rng++;
+            pz_indent =
+                (pOpts != OPTPROC_EMIT_USAGE) ? onetab : deepin;
         }
 
         if (pOpts > OPTPROC_EMIT_LIMIT)
@@ -105,15 +115,15 @@ optionNumericVal(tOptions* pOpts, tOptDesc* pOD )
     char* pz;
     long  val;
 
-    if ((pOD->fOptState & OPTST_RESET) != 0)
-        return;
-
     /*
      *  Numeric options may have a range associated with it.
      *  If it does, the usage procedure requests that it be
-     *  emitted by passing a NULL pOD pointer.
+     *  emitted by passing a NULL pOD pointer.  Also bail out
+     *  if there is no option argument or if we are being reset.
      */
-    if ((pOD == NULL) || (pOD->optArg.argString == NULL))
+    if (  (pOD == NULL)
+       || (pOD->optArg.argString == NULL)
+       || ((pOD->fOptState & OPTST_RESET) != 0))
         return;
 
     errno = 0;
@@ -148,7 +158,8 @@ optionNumericVal(tOptions* pOpts, tOptDesc* pOD )
     pOD->optArg.argInt = val;
     return;
 
-bad_number:
+    bad_number:
+
     fprintf( stderr, zNotNumber, pOpts->pzProgName, pOD->optArg.argString );
     if ((pOpts->fOptSet & OPTPROC_ERRSTOP) != 0)
         (*(pOpts->pUsageProc))(pOpts, EXIT_FAILURE);
